======================
TVDB for Django
======================

Write Django as usual, and let ``django-tvdb`` make handle api requests to theTVDB


.. image:: https://img.shields.io/travis/miigotu/django-tvdb/master.svg
    :target: https://travis-ci.org/miigotu/django-tvdb

.. image:: https://img.shields.io/coveralls/miigotu/django-tvdb/master.svg
  :target: https://coveralls.io/r/miigotu/django-tvdb?branch=master

.. image:: https://img.shields.io/pypi/v/django-tvdb.svg
    :target: https://pypi.python.org/pypi/django-tvdb
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-tvdb.svg
    :target: https://pypi.python.org/pypi/django-tvdb
    :alt: Number of PyPI downloads per month


Requirements
------------

- Python 2.7, 3.2, 3.3, 3.4, or 3.5
- Django >= 1.8

*The latest version supporting Python 2.6 and Django < 1.8 is the 6.x.x branch.*


Installation
------------

1. Install using pip:

   ``pip install django-tvdb``

   Alternatively, you can install download or clone this repo and call ``pip install -e .``.

2. Add to INSTALLED_APPS in your ``settings.py``:

   ``'tvdb',``


This app will soon require Django 1.8+, python 2.7+. Thanks for understanding.


Documentation
-------------

The full documentation is at http://django-tvdb.readthedocs.org/.
theTVDB API documentation is at https://api-beta.thetvdb.com/swagger

Bugs and suggestions
--------------------

If you have found a bug or if you have a request for additional functionality, please use the issue tracker on GitHub.

https://github.com/miigotu/django-tvdb/issues


License
-------

You can use this under Apache 2.0. See `LICENSE
<LICENSE>`_ file for details.


Author
------

Developed and maintained by `Zostera <https://zostera.nl/>`_.

Original author & Development lead: `Dylan Verheul <https://github.com/miigotu>`_.

Thanks to everybody that has contributed pull requests, ideas, issues, comments and kind words.

Please see AUTHORS.rst for a list of contributors.

